@@ -1,12 +1,14 @@
-#!/usr/local/bin/ruby24 --disable-gems
+#!/usr/local/bin/ruby34 --disable-gems
 
 $LOAD_PATH.unshift('/usr/local/share/gitsh/ruby/lib')
 
 require '/usr/local/share/gitsh/vendor/gems/setup.rb'
+require 'gitsh/environment'
 require 'gitsh/cli'
 
 begin
-  Gitsh::CLI.new.run
+  env = Gitsh::Environment.new(config_directory: '/etc/gitsh')
+  Gitsh::CLI.new(env: env).run
 rescue => e
   $stderr.puts "gitsh: Error: #{e.message}"
   exit 1
