@@ -4,13 +4,17 @@ require 'gitsh/commands/error_handler'
 module Gitsh
   module Commands
     class Factory
+      def self.build(*args)
+        new(*args).build
+      end
+
       def initialize(command_class, context)
         @command_class = command_class
         @context = context
-      end 
+      end
 
       def build
-        ErrorHandler.new(command_instance, env)
+        ErrorHandler.new(command_instance)
       end
 
       private
@@ -18,17 +22,13 @@ module Gitsh
       attr_reader :command_class, :context
 
       def command_instance
-        command_class.new(env, command, argument_list)
+        command_class.new(command, argument_list)
       end
 
       def argument_list
         ArgumentList.new(args)
       end
 
-      def env
-        context[:env]
-      end
-
       def command
         context[:command]
       end
