@@ -1,6 +1,7 @@
 require 'open3'
 require 'shellwords'
 require 'gitsh/git_repository/status'
+require 'gitsh/git_command_list'
 
 module Gitsh
   class GitRepository
@@ -32,13 +33,7 @@ module Gitsh
     end
 
     def commands
-      git_output('help -a').
-        lines.
-        select { |line| line =~ /^  [a-z]/ }.
-        map { |line| line.split(/\s+/) }.
-        flatten.
-        reject { |cmd| cmd.empty? || cmd =~ /--/ }.
-        sort
+      GitCommandList.new(env).to_a
     end
 
     def aliases
@@ -57,7 +52,7 @@ module Gitsh
         "config --get #{Shellwords.escape(name)}",
         force_default_git_command
       )
-      out, err, status = Open3.capture3(command)
+      out, _, status = Open3.capture3(command)
       if status.success?
         out.chomp
       elsif block_given?
@@ -67,6 +62,11 @@ module Gitsh
       end
     end
 
+    def available_config_variables
+      modern_git_available_config_variables ||
+        old_git_available_config_variables
+    end
+
     def config_color(name, default)
       git_output(
         "config --get-color #{Shellwords.escape(name)} #{Shellwords.escape(default)}"
@@ -118,6 +118,21 @@ module Gitsh
       end
     end
 
+    def modern_git_available_config_variables
+      command = git_command("config --list --name-only")
+      out, _, status = Open3.capture3(command)
+
+      if status.success?
+        out.lines.map { |line| line.chomp.to_sym }
+      end
+    end
+
+    def old_git_available_config_variables
+      git_output('config --list').lines.map do |line|
+        line.split('=').first.to_sym
+      end
+    end
+
     def git_output(command)
       Open3.capture3(git_command(command)).first.chomp
     end
