@@ -25,11 +25,19 @@ module Gitsh
       end
 
       def read_command
-        file.readline
+        next_line
       rescue EOFError
         nil
       end
 
+      def read_continuation
+        next_line
+      end
+
+      def handle_parse_error(message)
+        raise ParseError, message
+      end
+
       private
 
       attr_reader :env, :file, :path
@@ -41,6 +49,10 @@ module Gitsh
           ::File.open(path)
         end
       end
+
+      def next_line
+        file.readline.chomp
+      end
     end
   end
 end
